aboutsummaryrefslogtreecommitdiff
path: root/arch/arc/include/asm/mach_desc.h
diff options
context:
space:
mode:
authorVineet Gupta <vgupta@synopsys.com>2015-12-17 12:22:21 +0530
committerVineet Gupta <vgupta@synopsys.com>2015-12-17 12:56:56 +0530
commit575a9d4e2c09675c05db2bc781c5c33153ce932f (patch)
treee453e976683bd335919824f9dd4ed2e9af99d06d /arch/arc/include/asm/mach_desc.h
parentb474a02382b75f4a75c4e94eb9847aad28dd4a37 (diff)
ARC: smp: Rename platform hook @init_cpu_smp -> @init_per_cpu
Makes it similar to smp_ops which also has callback with same name Signed-off-by: Vineet Gupta <vgupta@synopsys.com>
Diffstat (limited to 'arch/arc/include/asm/mach_desc.h')
-rw-r--r--arch/arc/include/asm/mach_desc.h4
1 files changed, 2 insertions, 2 deletions
diff --git a/arch/arc/include/asm/mach_desc.h b/arch/arc/include/asm/mach_desc.h
index 6ff657a904b6..c28e6c347b49 100644
--- a/arch/arc/include/asm/mach_desc.h
+++ b/arch/arc/include/asm/mach_desc.h
@@ -23,7 +23,7 @@
* @dt_compat: Array of device tree 'compatible' strings
* (XXX: although only 1st entry is looked at)
* @init_early: Very early callback [called from setup_arch()]
* @init_cpu_smp: for each CPU as it is coming up (SMP as well as UP)
* [(M):init_IRQ(), (o):start_kernel_secondary()]
* @init_machine: arch initcall level callback (e.g. populate static
* platform devices or parse Devicetree)
@@ -35,7 +35,7 @@ struct machine_desc {
const char **dt_compat;
void (*init_early)(void);
#ifdef CONFIG_SMP
- void (*init_cpu_smp)(unsigned int);
+ void (*init_per_cpu)(unsigned int);
#endif
void (*init_machine)(void);
void (*init_late)(void);
@@ -23,7 +23,7 @@
* (XXX: although only 1st entry is looked at)
* @init_early: Very early callback [called from setup_arch()]
- * @init_cpu_smp: for each CPU as it is coming up (SMP as well as UP)
+ * @init_per_cpu: for each CPU as it is coming up (SMP as well as UP)
* [(M):init_IRQ(), (o):start_kernel_secondary()]
* @init_machine: arch initcall level callback (e.g. populate static